@@ -23,4 +23,4 @@ from PublicDataReader.PublicDataPortal.nts import Nts
 from PublicDataReader.kbland.kbland import Kbland
 
 # 코드 데이터 조회
-from PublicDataReader.utils.code import code_bdong, get_vworld_data_api_info_by_dataframe, get_vworld_data_api_info_by_dict
+from PublicDataReader.utils.code import code_bdong, code_hdong, code_hdong_bdong, get_vworld_data_api_info_by_dataframe, get_vworld_data_api_info_by_dict
